/*
        LG Game 1   - Ett spel av Legion Sommaren 2000


        Filformat fr level (.lev) filer:

        Beskrivning           | Offset | Bytes | vrigt
        ----------------------|--------| ------| ------
        Version och identitet | 0x0000 | 6     | Ska vara "LGL100"
        Namn p banan         | 0x0006 | 20    |
        Ban identitet         | 0x001A | 1     |
        Lngd i pixlar        | 0x001B | 2     | Hg byte frst
        Antal block i banan   | 0x001D | 2     | Hg byte frst
        Antal fiender i banan | 0x001F | 2     | Hg byte frst
        Antal saker i banan   | 0x0021 | 2     | Hg byte frst
        Spelarestart X        | 0x0023 | 2     | Hg byte frst
        Spelarestart Y        | 0x0025 | 2     | Hg byte frst
        Blocktyp              | 0x0027 | 1     |
        Blockposition X       | 0x0028 | 2     | Hg byte frst
        Blockposition Y       | 0x002A | 2     | Hg byte frst
        ...
        Fiendetyp             | ?      | 1     |
        Fiendeposition X      | ?      | 2     | Hg byte frst
        Fiendeposition Y      | ?      | 2     | Hg byte frst
        ...
        Saktyp                | ?      | 1     |
        Sakposition X         | ?      | 2     | Hg byte frst
        Sakposition Y         | ?      | 2     | Hg byte frst
        ...



        Jmna versionstal i den mittersta siffran r stabila
        Ojmna versionstal i den mittersta siffran r ostabila
        [*] = Fixad
        [+] = Nytt
        [-] = Borttaget
        [!] = Fel som ska fixas
        [/] = Inaktiverad
        [^] = Information

        Versionshistoria frn och med 2000-06-25 13:56

        V 0.6.0  2000-06-26 00:23
        -------------------------
         [^] DEBUG mode
         [^] Bakgrunden laddas, men ritas fr nrvarande inte ut
         [+] Ljudeffekter
         [+] Man kan dda fienderna
        -------------------------

        V 0.5.4  2000-06-25 22:41
        -------------------------
         [^] DEBUG mode
         [*] Fienderna rr sig lngsammare
         [+] Skada och ddsfunktion
         [+] Bakgrund
         [^] Bakgrunden laddas, men ritas fr nrvarande inte ut
        -------------------------

        V 0.5.1  2000-06-25 19:38
        -------------------------
         [^] DEBUG mode
         [*] Fler kommentarer
         [*] .lev filbeskrivning
         [+] Spelsync
         [-] Joystick/Joypad std
        -------------------------

        V 0.5.0  2000-06-25 13:56
        -------------------------
         [^] DEBUG mode
         [*] Musik
         [*] Bttre kommenterad kod
         [-] Spelsync
         [^] Denna version r endast till fr test av kompatiblitet
        -------------------------

*/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <midasdll.h>
#include <allegro.h>


#define TEXTURECOUNT 8  // Antal texturer som ska laddas
#define ENEMYCOUNT 3    // Antal fiendetexturer som ska laddas
#define ITEMCOUNT 3     // Antal saktexturer som ska laddas
#define SNDSAMPLECOUNT 4  // Antal ljudeffekter som ska laddas
#define MENUTEXT "T <->  E <->  I <-> PS Undo Exit"  // Den text som visas i levelcreatorn
#define NOMUSIC FALSE  // Om TRUE s r musiken avstngd
#define GAMESPEED 120000  // Ju strre desto snabbare
#define NOSYNC FALSE  // Om TRUE s r synkroniseringen avstngd
#define DEBUG TRUE  // Visar informationstexter
#define PLAYERBLINK 200 // Antal blinkningar nr man tar skada
#define WALKDELAY 3  // Antal loopar innan fienderna fr lov att flytta p sig...


struct TItemPos  // Sparar undan alla variabler som ett objekt kan tnkas behva
{
  int ident;
  int Visible;
  long x;
  long y;
  long StartX;
  long StartY;
  int xdec, xinc;
  int Colll, Collr;
  int Dir;
  int fall;
  int WalkDelay;
} TItemPos;

struct TLevelMask     // Kollisionsmask fr banan
{
  int mask:4; // OBS! endast fyra bitar
};

typedef struct TLevelData  // Alla variabler som har med den aktulla banan att gra
{
  unsigned int Length;
  BITMAP *LevelBitmap;
  BITMAP *Background;
  PALETTE Pal;
  char Name[20];
  unsigned char ident;
  unsigned int BlockCount;
  unsigned int EnemyCount;
  unsigned int ItemCount;
  unsigned int xoff;
  int xinc, xdec;
  struct TItemPos *BlockPos;     // Allokeras dynamiskt vid inladdning av banan
  struct TItemPos *EnemyPos;     // -//-
  struct TItemPos *ItemPos;      // -//-
  struct TLevelMask *LevelMask;  // -//-
  int Scroll;
} TLevelData;


typedef struct TTexture     // Information om texturer
{
  BITMAP *Bitmap;
  unsigned int Width;
  unsigned int Height;
  PALETTE Pal;
} TTexture;

typedef struct TPlayerInfo  // Alla variabler som behvs fr att styra spelaren
{
  BITMAP *Bitmap1, *Bitmap2;
  unsigned int x;
  unsigned int y;
  unsigned int StartX;
  unsigned int StartY;
  int xdec, xinc;
  int xdecj, xincj;
  int jump, fall;
  unsigned int jumpx, jumpy;
  int Colll, Collr;
  PALETTE Pal;
  int Dir;
  unsigned long Score;
  int Blink, BlinkCount;
  int Health;
} TPlayerInfo;

typedef struct TEnemyInfo  // Alla variabler som behvs fr fiendetexturer
{
  BITMAP *Bitmap1, *Bitmap2;
  PALETTE Pal;
} TEnemyInfo;

typedef struct TItemInfo  // Alla variabler som behvs fr Saktexturer
{
  BITMAP *Bitmap1, *Bitmap2;
  PALETTE Pal;
} TItemInfo;

typedef struct TSndSample  // Alla variabler som behvs fr Saktexturer
{
  MIDASsample Sample;
  MIDASsamplePlayHandle Handle;
} TSndSample;


int gKey=0;            // Innehller vilken knapp man tryckte p
int  gfxmode=GFX_TEXT, joyen=FALSE, mouseen=TRUE;
TLevelData LevelData;
TTexture Texture[TEXTURECOUNT];
TPlayerInfo Player;
TEnemyInfo Enemy[ENEMYCOUNT];
TItemInfo Item[ITEMCOUNT];
TSndSample SndSample[SNDSAMPLECOUNT];
MIDASmodule testmod;
MIDASmodulePlayHandle playHandle;
BITMAP *Vir1;
struct TItemPos *TempPos;
int Refr=FALSE;
int Design=FALSE;
int JumpPathNum=0;   // JumpPath bestmmer hur spelaren ska hoppa
int JumpPath[80] = {1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,1,1,1,0,1,1,1,1,0,
                    1,1,0,0,1,0,1,1,0,1,0,0,1,0,1,0,0,1,0,1,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,1,1};

int equit(char *exitstr)  // Stnger ner programmet och visar ett felmeddelande
{
  if (gfxmode!=GFX_TEXT)
    set_gfx_mode(GFX_TEXT, 640, 480, 0, 0);
  printf("Error!\n  - %s",exitstr);
  if (Design)
    remove_mouse();
  if (joyen)
    remove_joystick();
  remove_keyboard();
  allegro_exit();
  exit(1);
  return 0;
}

int quit(char *exitstr)  // Stnger programmet och visar ett meddelande
{
  if (gfxmode!=GFX_TEXT)
    set_gfx_mode(GFX_TEXT, 640, 480, 0, 0);
  printf("%s",exitstr);
  if (joyen)
    remove_joystick();
  remove_keyboard();
  allegro_exit();
  exit(0);
  return 0;
}

void KeyRelease(int Key)    // Kallas vid keyboard interupt
{
  if (Key & 0x80)
  {
    switch(Key & 127)   // Nr man slpper knappen
    {
      case  31 : Player.xdec=FALSE;
                 break;
      case  33 : Player.xinc=FALSE;
                 break;
      case  77:  if (Design)
                   LevelData.xinc=FALSE;
                 else
                   Player.xinc=FALSE;
                 break;
      case  75:  if (Design)
                   LevelData.xdec=FALSE;
                 else
                   Player.xdec=FALSE;
                 break;
    }
  }
  else
  {
    switch(Key & 127)    // Nr man trycker...
    {
      case  18 : if ((!Player.fall) && (!Player.jump)/* && (!PreventExtraJump)*/)
                 {
                   if (!NOMUSIC)
                     SndSample[2].Handle=MIDASplaySample(SndSample[2].Sample, 15, 0, 22050, 80, MIDAS_PAN_MIDDLE);
                   Player.jump=TRUE;
                   Player.jumpx=Player.x;
                   Player.jumpy=Player.y;
                   JumpPathNum=0;
                 }
                 break;
      case  72 : if ((!Player.fall) && (!Player.jump)/* && (!PreventExtraJump)*/)
                 {
                   if (!NOMUSIC)
                     SndSample[2].Handle=MIDASplaySample(SndSample[2].Sample, 15, 0, 22050, 80, MIDAS_PAN_MIDDLE);
                   Player.jump=TRUE;
                   Player.jumpx=Player.x;
                   Player.jumpy=Player.y;
                   JumpPathNum=0;
                 }
                 break;
      case  31 : Player.xdec=TRUE;
                 Player.Dir=1;
                 break;
      case  33 : Player.xinc=TRUE;
                 Player.Dir=0;
                 break;
      case  77:  if (Design)
                   LevelData.xinc=TRUE;
                 else
                 {
                   Player.xinc=TRUE;
                   Player.Dir=0;
                 }
                 break;
      case  75:  if (Design)
                   LevelData.xdec=TRUE;
                 else
                 {
                   Player.xdec=TRUE;
                   Player.Dir=1;
                 }
                 break;
    }
  }
}

unsigned short hi(unsigned int inpt)  // Returnerar den hga byten
{
  return ((inpt & 0xFF00) >> 8);
}

unsigned short lo(unsigned int inpt)  // Returnerar den lga byten
{
  return (inpt & 0x00FF);
}


int update_level()
{
/*  int x;
  x=LevelData.xoff;
  if (x==320)
    x=0;
  blit(LevelData.Background, Vir1, x,0,0,10,320,190);
  if (LevelData.xoff>0)
    blit(LevelData.Background, Vir1, 0,0,x,10,320-x,190);*/
  /*masked_*/blit(LevelData.LevelBitmap, Vir1, LevelData.xoff,0,0,10, 320,190);
  hline(Vir1, 0, 9, 320, 100);
  textprintf(Vir1, font, 0,0, 100, "%s  Score: %i  Health: %i", LevelData.Name, Player.Score, Player.Health);
 // textprintf(Vir1, font, 0,0,100, "Jump: %i", Player.jump);
 return 0;
}


int player_die()
{
  int y=0, a=0;
  if ((!Design))
  {
    if (!NOMUSIC)
      MIDASstopModule(playHandle);
  }
  y=Player.y;
  while ((y-30)<Player.y)
  {
    Player.y--;
    update_level();
    if (Player.Dir==0)
      draw_sprite(Vir1, Player.Bitmap1, Player.x, Player.y);
    if (Player.Dir==1)
      draw_sprite(Vir1, Player.Bitmap2, Player.x, Player.y);
    if (!NOSYNC)
      while (!Refr) {}
    blit(Vir1, screen, 0,0,0,0, 320,200);
  }
  while (Player.y<200)
  {
    Player.y++;
    update_level();
    if (Player.Dir==0)
      draw_sprite(Vir1, Player.Bitmap1, Player.x, Player.y);
    if (Player.Dir==1)
      draw_sprite(Vir1, Player.Bitmap2, Player.x, Player.y);
    if (!NOSYNC)
      while (!Refr) {}
    blit(Vir1, screen, 0,0,0,0, 320,200);
  }
  Player.x=Player.StartX;
  Player.y=Player.StartY;
  for (a=0;a<LevelData.EnemyCount;a++)
  {
    LevelData.EnemyPos[a].x=LevelData.EnemyPos[a].StartX;
    LevelData.EnemyPos[a].y=LevelData.EnemyPos[a].StartY;
    LevelData.EnemyPos[a].Visible=TRUE;
  }
  for (a=0;a<LevelData.ItemCount;a++)
  {
    LevelData.ItemPos[a].Visible=TRUE;
  }
  Player.Score=0;
  LevelData.xoff=0;
  Player.Health=3;
  Player.Blink=FALSE;
  Player.BlinkCount=0;
  clear(Vir1);
  clear(screen);
  //readkey();
  if ((!Design))
  {
    if ((!Design) && (!NOMUSIC))
      playHandle=MIDASplayModule(testmod, TRUE);
  }
  return 0;
}

int player_hurt()
{
  if (!NOMUSIC)
    SndSample[3].Handle=MIDASplaySample(SndSample[3].Sample, 14, 0, 22050, 80, MIDAS_PAN_MIDDLE);
  Player.Health--;
  if (Player.Health<1)
  {
    player_die();
  }
  Player.Blink=TRUE;
  Player.BlinkCount=PLAYERBLINK;
  return 0;
}


int update_items()
{
  int a;
  for (a=0;a<LevelData.ItemCount;a++)
  {
    if (LevelData.ItemPos[a].Visible)
      draw_sprite(Vir1, Item[LevelData.ItemPos[a].ident].Bitmap1, LevelData.ItemPos[a].x-LevelData.xoff, LevelData.ItemPos[a].y+10);
  }
  return 0;
}

int update_enemies()
{
  int i, a;
  for (i=0;i<LevelData.EnemyCount;i++)
  {
    if (LevelData.EnemyPos[i].Visible)
    {
      LevelData.EnemyPos[i].Colll=LevelData.EnemyPos[i].Collr=FALSE;
      LevelData.EnemyPos[i].fall=TRUE;

      for (a=0;a<Enemy[LevelData.EnemyPos[i].ident].Bitmap1->w;a++)
        if ((LevelData.LevelMask[((LevelData.EnemyPos[i].y+Enemy[LevelData.EnemyPos[i].ident].Bitmap1->h-10)*LevelData.Length)+(LevelData.EnemyPos[i].x/*+LevelData.xoff*/+a)].mask!=0))
          LevelData.EnemyPos[i].fall=FALSE;

      for (a=0;a<Enemy[LevelData.EnemyPos[i].ident].Bitmap1->h;a++)
        if ((LevelData.LevelMask[((LevelData.EnemyPos[i].y-10+a)*LevelData.Length)+(LevelData.EnemyPos[i].x/*+LevelData.xoff*/-1)].mask!=0))
          LevelData.EnemyPos[i].Colll=TRUE;

      for (a=0;a<Enemy[LevelData.EnemyPos[i].ident].Bitmap1->h;a++)
        if ((LevelData.LevelMask[((LevelData.EnemyPos[i].y-10+a)*LevelData.Length)+(LevelData.EnemyPos[i].x+Enemy[LevelData.EnemyPos[i].ident].Bitmap1->w/*+LevelData.xoff*/)].mask!=0))
          LevelData.EnemyPos[i].Collr=TRUE;

      if (LevelData.EnemyPos[i].fall)
        if ((LevelData.EnemyPos[i].y+Enemy[LevelData.EnemyPos[i].ident].Bitmap1->h)<200)
          LevelData.EnemyPos[i].y++;

      if (LevelData.EnemyPos[i].Colll)
      {
        LevelData.EnemyPos[i].xinc=TRUE;
        LevelData.EnemyPos[i].xdec=FALSE;
        LevelData.EnemyPos[i].Colll=FALSE;
      }
      if (LevelData.EnemyPos[i].Collr)
      {
        LevelData.EnemyPos[i].xdec=TRUE;
        LevelData.EnemyPos[i].xinc=FALSE;
        LevelData.EnemyPos[i].Collr=FALSE;
      }

      LevelData.EnemyPos[i].WalkDelay--;

      if ((LevelData.EnemyPos[i].xdec) && (!LevelData.EnemyPos[i].fall) && (LevelData.EnemyPos[i].x>0) && (LevelData.EnemyPos[i].WalkDelay==0))
        LevelData.EnemyPos[i].x--;
      if ((LevelData.EnemyPos[i].xinc) && (!LevelData.EnemyPos[i].fall) && (LevelData.EnemyPos[i].x<LevelData.Length) && (LevelData.EnemyPos[i].WalkDelay==0))
        LevelData.EnemyPos[i].x++;
  
      if (LevelData.EnemyPos[i].WalkDelay<1)
        LevelData.EnemyPos[i].WalkDelay=WALKDELAY;
  
    //  if ((Enemy[i].x+Enemy[i].Bitmap1->w)<(320-LevelData.xoff))
      draw_sprite(Vir1, Enemy[LevelData.EnemyPos[i].ident].Bitmap1, LevelData.EnemyPos[i].x-LevelData.xoff, LevelData.EnemyPos[i].y);
      //textprintf(Vir1, font, 0,0,100, "Cll %i Clr %i xi %i xd %i F %i X %i Y %i", LevelData.EnemyPos[i].Colll, LevelData.EnemyPos[i].Collr, LevelData.EnemyPos[i].xinc, LevelData.EnemyPos[i].xdec, LevelData.EnemyPos[i].fall, LevelData.EnemyPos[i].x, LevelData.EnemyPos[i].y);
    }
  }
}


int update_player()
{
  int a, px1, px2, py1, py2;
  Player.fall=TRUE;
  LevelData.Scroll=FALSE;
 // PreventExtraJump=FALSE;
  Player.Colll=Player.Collr=FALSE;
  if (Player.y<Player.jumpy-30)
  {
    //PreventExtraJump=TRUE;
    Player.jump=FALSE;
  }
/*  if ((!Player.jump) &&
      (_getpixel(Vir1, Player.x+0, Player.y+Player.Bitmap1->h)==0) &&
      (_getpixel(Vir1, Player.x+1, Player.y+Player.Bitmap1->h)==0) &&
      (_getpixel(Vir1, Player.x+2, Player.y+Player.Bitmap1->h)==0) &&
      (_getpixel(Vir1, Player.x+3, Player.y+Player.Bitmap1->h)==0) &&
      (_getpixel(Vir1, Player.x+4, Player.y+Player.Bitmap1->h)==0) &&
      (_getpixel(Vir1, Player.x+5, Player.y+Player.Bitmap1->h)==0) &&
      (_getpixel(Vir1, Player.x+6, Player.y+Player.Bitmap1->h)==0) &&
      (_getpixel(Vir1, Player.x+7, Player.y+Player.Bitmap1->h)==0) &&
      (_getpixel(Vir1, Player.x+8, Player.y+Player.Bitmap1->h)==0) &&
      (_getpixel(Vir1, Player.x+9, Player.y+Player.Bitmap1->h)==0))
  {
    Player.fall=TRUE;
    PreventExtraJump=FALSE;
    //Player.ydec=FALSE;
    //Player.yinc=FALSE;
  }
  else
    PreventExtraJump=FALSE;*/
/*  for (a=0;a<Player.Bitmap1->w;a++)
    if (_getpixel(screen, Player.x+a, Player.y-1)!=0)
      Player.jump=FALSE;
  Player.Colll=FALSE;
  for (a=0;a<Player.Bitmap1->h;a++)
    if (_getpixel(screen, Player.x-1, Player.y+a)!=0)
    {
      //Player.xdec=FALSE;
      //Player.xdecj=FALSE;
      Player.Colll=TRUE;
    }
  Player.Collr=FALSE;
  for (a=0;a<Player.Bitmap1->h;a++)
    if (_getpixel(screen, Player.x+Player.Bitmap1->w, Player.y+a)!=0)
    {
      //Player.xinc=FALSE;
      //Player.xincj=FALSE;
      Player.Collr=TRUE;
    }                   */
/*
  px1=Player.x+LevelData.xoff;
  px2=Player.x+Player.Bitmap1->w+LevelData.xoff;
  py1=Player.y+Player.Bitmap1->h;
  py2=Player.y;

  for (a=0;a<LevelData.ItemCount;a++)
  {
    if ((px2>LevelData.ItemPos[a].x) && (px1<LevelData.ItemPos[a].x+Texture[LevelData.ItemPos[a].ident].Bitmap->w) && (py1==LevelData.ItemPos[a].y) || (Player.jump))
    {
      Player.fall=FALSE;
      PreventExtraJump=FALSE;
    }
    if ((((LevelData.ItemPos[a].y+Texture[LevelData.ItemPos[a].ident].Bitmap->h)>Player.y) && (LevelData.ItemPos[a].y<Player.y+Player.Bitmap1->h)) && ((LevelData.ItemPos[a].x+Texture[LevelData.ItemPos[a].ident].Bitmap->w)==Player.x+LevelData.xoff))
    {
      Player.Colll=TRUE;
    }
    if (((LevelData.ItemPos[a].y+Texture[LevelData.ItemPos[a].ident].Bitmap->h)>Player.y) && (LevelData.ItemPos[a].y<(Player.y+Player.Bitmap1->h)) && (LevelData.ItemPos[a].x==(Player.x+Player.Bitmap1->w+LevelData.xoff)))
    {
      Player.Collr=TRUE;
    }
    if (((LevelData.ItemPos[a].x+Texture[LevelData.ItemPos[a].ident].Bitmap->w)>(Player.x+LevelData.xoff)) && (LevelData.ItemPos[a].x<(Player.x+Player.Bitmap1->w+LevelData.xoff)) && ((LevelData.ItemPos[a].y+Texture[LevelData.ItemPos[a].ident].Bitmap->h)==Player.y))
    {
      Player.jump=FALSE;
      Player.fall=TRUE;
    }
  }
   */
  for (a=0;a<Player.Bitmap1->w;a++)
    if ((LevelData.LevelMask[((Player.y+Player.Bitmap1->h-10)*LevelData.Length)+(Player.x+LevelData.xoff+a)].mask!=0))
      Player.fall=FALSE;

  for (a=0;a<Player.Bitmap1->h;a++)
    if ((LevelData.LevelMask[((Player.y-10+a)*LevelData.Length)+(Player.x+LevelData.xoff-1)].mask!=0))
      Player.Colll=TRUE;

  for (a=0;a<Player.Bitmap1->h;a++)
    if ((LevelData.LevelMask[((Player.y-10+a)*LevelData.Length)+(Player.x+Player.Bitmap1->w+LevelData.xoff)].mask!=0))
      Player.Collr=TRUE;

  for (a=0;a<Player.Bitmap1->w;a++)
    if ((LevelData.LevelMask[((Player.y-10-1)*LevelData.Length)+(Player.x+LevelData.xoff+a)].mask!=0))
    {
      Player.jump=FALSE;
     // Player.fall=TRUE;
    }

  for (a=0;a<LevelData.EnemyCount;a++)
  {
    if (LevelData.EnemyPos[a].Visible)
    {
      if (((LevelData.EnemyPos[a].y+Enemy[LevelData.EnemyPos[a].ident].Bitmap1->h)>Player.y) && (LevelData.EnemyPos[a].y<(Player.y+Player.Bitmap1->h)) && (LevelData.EnemyPos[a].x==(Player.x+Player.Bitmap1->w+LevelData.xoff)))
        if (!Player.Blink)
        {
          if (!NOMUSIC)
            SndSample[1].Handle=MIDASplaySample(SndSample[1].Sample, 15, 0, 22050, 80, MIDAS_PAN_MIDDLE);
          player_hurt();
        }
      if (((LevelData.EnemyPos[a].y+Enemy[LevelData.EnemyPos[a].ident].Bitmap1->h)>Player.y) && (LevelData.EnemyPos[a].y<(Player.y+Player.Bitmap1->h)) && ((LevelData.EnemyPos[a].x+Enemy[LevelData.EnemyPos[a].ident].Bitmap1->w)==(Player.x+LevelData.xoff)))
        if (!Player.Blink)
        {
          if (!NOMUSIC)
            SndSample[1].Handle=MIDASplaySample(SndSample[1].Sample, 15, 0, 22050, 80, MIDAS_PAN_MIDDLE);
          player_hurt();
        }
      if (((LevelData.EnemyPos[a].x+Enemy[LevelData.EnemyPos[a].ident].Bitmap1->w)>(Player.x+LevelData.xoff)) && (LevelData.EnemyPos[a].x<(Player.x+Player.Bitmap1->w+LevelData.xoff)) && (LevelData.EnemyPos[a].y==(Player.y+Player.Bitmap1->h)) && (!Player.jump))
      {
        if (!NOMUSIC)
          SndSample[0].Handle=MIDASplaySample(SndSample[0].Sample, 16, 0, 22050, 80, MIDAS_PAN_MIDDLE);
        LevelData.EnemyPos[a].Visible=FALSE;
        Player.Score+=(LevelData.EnemyPos[a].ident+1)*100;
        Player.jump=TRUE;
      }
    }
  }
  if (Player.y+Player.Bitmap1->h>199)
  {
    if (!NOMUSIC)
      SndSample[1].Handle=MIDASplaySample(SndSample[1].Sample, 15, 0, 22050, 80, MIDAS_PAN_MIDDLE);
    player_die();
  }

  for (a=0;a<LevelData.ItemCount;a++)
  {
    if (((LevelData.ItemPos[a].y+Item[LevelData.ItemPos[a].ident].Bitmap1->h+10)>Player.y) && ((LevelData.ItemPos[a].y+10)<(Player.y+Player.Bitmap1->h)) && (LevelData.ItemPos[a].x==(Player.x+Player.Bitmap1->w+LevelData.xoff)) && (LevelData.ItemPos[a].Visible))
    {
      LevelData.ItemPos[a].Visible=FALSE;
      Player.Score+=(LevelData.ItemPos[a].ident+1)*25;
      if (!NOMUSIC)
        SndSample[1].Handle=MIDASplaySample(SndSample[1].Sample, 15, 0, 22050, 80, MIDAS_PAN_MIDDLE);
    }
    if (((LevelData.ItemPos[a].y+Item[LevelData.ItemPos[a].ident].Bitmap1->h+10)>Player.y) && ((LevelData.ItemPos[a].y+10)<(Player.y+Player.Bitmap1->h)) && ((LevelData.ItemPos[a].x+Item[LevelData.ItemPos[a].ident].Bitmap1->w)==(Player.x+LevelData.xoff)) && (LevelData.ItemPos[a].Visible))
    {
      LevelData.ItemPos[a].Visible=FALSE;
      Player.Score+=(LevelData.ItemPos[a].ident+1)*25;
      if (!NOMUSIC)
        SndSample[1].Handle=MIDASplaySample(SndSample[1].Sample, 15, 0, 22050, 80, MIDAS_PAN_MIDDLE);
    }
    if ((LevelData.ItemPos[a].x<(Player.x+Player.Bitmap1->w+LevelData.xoff)) && ((LevelData.ItemPos[a].x+Item[LevelData.ItemPos[a].ident].Bitmap1->w)>(Player.x+LevelData.xoff)) && ((LevelData.ItemPos[a].y+10)==(Player.y+Player.Bitmap1->h)) && (LevelData.ItemPos[a].Visible))
    {
      LevelData.ItemPos[a].Visible=FALSE;
      Player.Score+=(LevelData.ItemPos[a].ident+1)*25;
      if (!NOMUSIC)
        SndSample[1].Handle=MIDASplaySample(SndSample[1].Sample, 15, 0, 22050, 80, MIDAS_PAN_MIDDLE);
    }
    if ((LevelData.ItemPos[a].x<(Player.x+Player.Bitmap1->w+LevelData.xoff)) && ((LevelData.ItemPos[a].x+Item[LevelData.ItemPos[a].ident].Bitmap1->w)>(Player.x+LevelData.xoff)) && ((LevelData.ItemPos[a].y+Item[LevelData.ItemPos[a].ident].Bitmap1->h+10)==Player.y) && (LevelData.ItemPos[a].Visible))
    {
      LevelData.ItemPos[a].Visible=FALSE;
      Player.Score+=(LevelData.ItemPos[a].ident+1)*25;
      if (!NOMUSIC)
        SndSample[1].Handle=MIDASplaySample(SndSample[1].Sample, 15, 0, 22050, 80, MIDAS_PAN_MIDDLE);
    }
  }

  if (Player.jump)
    Player.fall=FALSE;

  if (Player.fall)
  {
    if (Player.y<(200-Player.Bitmap1->h))
      Player.y+=JumpPath[JumpPathNum];
    if (JumpPathNum>0)
      JumpPathNum--;
  }
  if (((Player.xdec) || (Player.xdecj)) && (!Player.Colll))
    if (Player.x>0)
      Player.x--;
  if (((Player.xinc) || (Player.xincj)) && (!Player.Collr))
    if (Player.x<(320-Player.Bitmap1->w))
      Player.x++;
  if (Player.jump)
  {
    Player.y-=JumpPath[JumpPathNum];
    if (JumpPathNum<79)
      JumpPathNum++;
  }
/*  if (Player.yinc)
    Player.y++;*/
  if ((Player.x>(320-100)))
    if (LevelData.xoff<(LevelData.Length-320))
    {
     LevelData.xoff++;
     Player.x--;
     LevelData.Scroll=TRUE;
    }
  if ((Player.x<100))
    if (LevelData.xoff>0)
    {
      LevelData.xoff--;
      Player.x++;
      LevelData.Scroll=TRUE;
    }
  //masked_blit(Player.Bitmap, Vir1, 0, 0, Player.x, Player.y, Player.Bitmap->w, Player.Bitmap->h);
  if (Player.Blink)
  {
    Player.BlinkCount--;
    if (Player.BlinkCount<1)
    {
      Player.BlinkCount=PLAYERBLINK;
      Player.Blink=FALSE;
    }
    if (Player.BlinkCount % 2 == 0)
    {
      if (Player.Dir==0)
        draw_sprite(Vir1, Player.Bitmap1, Player.x, Player.y);
      if (Player.Dir==1)
        draw_sprite(Vir1, Player.Bitmap2, Player.x, Player.y);
    }
  }
  else
  {
    if (Player.Dir==0)
      draw_sprite(Vir1, Player.Bitmap1, Player.x, Player.y);
    if (Player.Dir==1)
      draw_sprite(Vir1, Player.Bitmap2, Player.x, Player.y);
  }
}


int get_input()     // Hmtar aktuell knapptryckning och joystick data
{
  if (keypressed())
  {
    gKey=readkey();
  }
  if (joyen)
  {
    poll_joystick();
  }
  return 0;
}

int load_level(char *filename)
{
  FILE *F;
  char *temp;
  int i, j;
  unsigned char BlockType;
  unsigned int x,y;
  unsigned int ItemCount;
  if (DEBUG)
    printf("Loading level: %s\n", filename);
  F=fopen(filename, "r");
  if (F==0)
  {
     equit("Error opening file!");
  }
  else
  {
    fgets(temp, 7, F);  // Kollar om filen har rtt format
    if (strcmp(temp, "LGL100")!=0)
      equit("Wrong filetype!");
    else
    {    // Laddar banans namn
      fgets(LevelData.Name, 20, F);
      fgetc(F);
      LevelData.ident=fgetc(F);   // Identifikationsnummer
      if (DEBUG)
        printf("Ident: %i\n", LevelData.ident);
      LevelData.Length=fgetc(F);  // Banans lngd i pixlar
      LevelData.Length=(LevelData.Length << 8);
      LevelData.Length+=fgetc(F);
      if (DEBUG)
        printf("Length: %i\n", LevelData.Length);
      LevelData.BlockCount=fgetc(F);  // Antal block i banan
      LevelData.BlockCount=(LevelData.BlockCount << 8);
      LevelData.BlockCount+=fgetc(F);
      if (DEBUG)
        printf("BlockCount: %i\n", LevelData.BlockCount);
      LevelData.EnemyCount=fgetc(F);   // Antal fiender p banan
      LevelData.EnemyCount=(LevelData.EnemyCount << 8);
      LevelData.EnemyCount+=fgetc(F);
      if (DEBUG)
        printf("EnemyCount: %i\n", LevelData.EnemyCount);
      LevelData.ItemCount=fgetc(F);   // Antal prylar och saker p banan
      LevelData.ItemCount=(LevelData.ItemCount << 8);
      LevelData.ItemCount+=fgetc(F);
      if (DEBUG)
        printf("ItemCount: %i\n", LevelData.ItemCount);
      Player.x=fgetc(F);   // Player start X
      Player.x=(Player.x << 8);
      Player.x+=fgetc(F);
      if (DEBUG)
        printf("Player.x: %i\n", Player.x);
      Player.y=fgetc(F);   // Player start Y
      Player.y=(Player.y << 8);
      Player.y+=fgetc(F);
      Player.StartX=Player.x;
      Player.StartY=Player.y;
      if (DEBUG)
        printf("Player.y: %i\n", Player.y);
      // printf("Loading %s - %i\n", LevelData.Name, LevelData.Ident);
      if (DEBUG)
        printf("Allokerar minne...\n");
      LevelData.LevelBitmap=create_bitmap(LevelData.Length, 190);   // Allokerar minne fr banbitmappen
      LevelData.LevelMask=malloc(sizeof(struct TLevelMask)*((LevelData.Length*190)+10));  //Allokerar minne fr collisionmasken
      if (LevelData.LevelMask==0)
        equit("Not enough memory...");
      LevelData.BlockPos=malloc(sizeof(struct TItemPos)*LevelData.BlockCount+10);  // Allokerar minne fr block
      if (LevelData.BlockPos==0)
        equit("Not enough memory...");
      LevelData.EnemyPos=malloc(sizeof(struct TItemPos)*LevelData.EnemyCount+10);  // Allokerar minne fr fiender
      if (LevelData.EnemyPos==0)
        equit("Not enough memory...");
      LevelData.ItemPos=malloc(sizeof(struct TItemPos)*LevelData.ItemCount+10);    // Allokerar minne fr saker
      if (LevelData.ItemPos==0)
        equit("Not enough memory...");
      memset(LevelData.LevelMask, 0, (LevelData.Length*190)+10);          // Nollstller alla allokerade minnesplatser
      memset(LevelData.BlockPos, 0, LevelData.BlockCount+10);
      memset(LevelData.EnemyPos, 0, LevelData.EnemyCount+10);
      memset(LevelData.ItemPos, 0, LevelData.ItemCount+10);
      clear(LevelData.LevelBitmap);
      if ((LevelData.LevelBitmap==NULL))
        equit("Error creating bitmaps!");
      else // Ladda sjlva banan...
      {
        if (DEBUG)
          printf("Laddar koordinater till block\n");
        for (i=0;i<LevelData.BlockCount;i++)
        {
          BlockType=fgetc(F);  // Hmta blocktypen
          if (BlockType<TEXTURECOUNT)  // Kontrollera om det r ett felaktigt block
          {
            if (DEBUG)
              printf(".");
            x=fgetc(F);   // Hmta X och Y position fr blocket
            x=(x << 8);
            x+=fgetc(F);
            y=fgetc(F);
            y=(y << 8);
            y+=fgetc(F);
            masked_blit(Texture[BlockType].Bitmap, LevelData.LevelBitmap,  0, 0, x, y, Texture[BlockType].Width, Texture[BlockType].Height);
            LevelData.BlockPos[i].x=x;  // Sparar blocket i minnet
            LevelData.BlockPos[i].y=y;
            LevelData.BlockPos[i].ident=BlockType;
          }
        }
        if (DEBUG)
          printf("\nLaddar koordinater till fiender\n");
        for (i=0;i<LevelData.EnemyCount;i++)  // Samma som ovan fast fr fiender
        {
          BlockType=fgetc(F);
          if (BlockType<ENEMYCOUNT)
          {
            if (DEBUG)
              printf(".");
            x=fgetc(F);
            x=(x << 8);
            x+=fgetc(F);
            y=fgetc(F);
            y=(y << 8);
            y+=fgetc(F);
            //masked_blit(Enemy[BlockType].Bitmap1, LevelData.LevelBitmap,  0, 0, x, y, Enemy[BlockType].Bitmap1->w, Enemy[BlockType].Bitmap1->h);
            LevelData.EnemyPos[i].x=x;
            LevelData.EnemyPos[i].y=y;//+10
            LevelData.EnemyPos[i].StartX=x;
            LevelData.EnemyPos[i].StartY=y;//+10
            LevelData.EnemyPos[i].ident=BlockType;
            LevelData.EnemyPos[i].xdec=TRUE;
            LevelData.EnemyPos[i].xinc=FALSE;
            LevelData.EnemyPos[i].WalkDelay=WALKDELAY;
            LevelData.EnemyPos[i].Visible=TRUE;
          }
        }
        if (DEBUG)
          printf("\nLaddar koordinater till saker\n");
        for (i=0;i<LevelData.ItemCount;i++)   // Samma som ovan fast fr saker
        {
          BlockType=fgetc(F);
        /*  if (DEBUG)
            printf("[%i]", BlockType);*/
          if (BlockType<ITEMCOUNT)
          {
            if (DEBUG)
              printf(".");
            x=fgetc(F);
            x=(x << 8);
            x+=fgetc(F);
            y=fgetc(F);
            y=(y << 8);
            y+=fgetc(F);
            //masked_blit(Item[BlockType].Bitmap1, LevelData.LevelBitmap,  0, 0, x, y, Item[BlockType].Bitmap1->w, Item[BlockType].Bitmap1->h);
            LevelData.ItemPos[i].x=x;
            LevelData.ItemPos[i].y=y;
            LevelData.ItemPos[i].ident=BlockType;
            LevelData.ItemPos[i].Visible=TRUE;
          }
        }
      }
    }
    if (DEBUG)
      printf("\nSkapar LevelMask...\n");
    for (i=0;i<190;i++)
    {
      for (j=0;j<LevelData.Length;j++)
      {
        if (getpixel(LevelData.LevelBitmap, j, i)>0)
        LevelData.LevelMask[(i*LevelData.Length)+j].mask=1;
        else
        LevelData.LevelMask[(i*LevelData.Length)+j].mask=0;
      }
    }
    if (DEBUG)
      printf("Klart!\n");
  }
  fclose(F);
  return 0;
}

int unload_level()
{
  int a;
  if (LevelData.LevelBitmap!=0)
    destroy_bitmap(LevelData.LevelBitmap);
  LevelData.Length=0;
  for (a=0;a<20;a++)
    LevelData.Name[a]=' ';
  LevelData.ident=0;
  LevelData.BlockCount=0;
  LevelData.EnemyCount=0;
  LevelData.ItemCount=0;
  free(LevelData.LevelMask);
  free(LevelData.BlockPos);
  free(LevelData.EnemyPos);
  free(LevelData.ItemPos);
  return 0;
}


int design_new_level(char *filename)
{
  FILE *F;
  int ActiveItem=0, ActiveEnemy=0, ActiveTexture=0, draw=TRUE, done=FALSE, change_text=TRUE;
  int a;
  BITMAP *TempBitmap, *PlayerStartBitmap;

  char *temp;
  int i, j;
  unsigned char BlockType;
  unsigned int x,y;
//  unsigned int BlockCount=0, ItemCount=0, EnemyCount=0;
  int ItemType=0;
  int PlayerStartSet=FALSE;

  // On filen finns s ppna ladda den i minnet
  // Om inte skapa en ny

  if (exists(filename)!=0)
  {
/*    load_level!!!!*/

    F=fopen(filename, "r");
    if (F==0)
    {
       equit("Cant open file!");
    }
    else
    {
      fgets(temp, 7, F);  // Kollar om filen har rtt format
      if (strcmp(temp, "LGL100")!=0)
        equit("Wrong filetype!\n");
      else
      {    // Laddar banans namn
        fgets(LevelData.Name, 20, F);
        fgetc(F);
        LevelData.ident=fgetc(F);   // Identifikationsnummer
        LevelData.Length=fgetc(F);  // Banans lngd i pixlar
        LevelData.Length=(LevelData.Length << 8);
        LevelData.Length+=fgetc(F);
        LevelData.BlockCount=fgetc(F);  // Antal block i banan
        LevelData.BlockCount=(LevelData.BlockCount << 8);
        LevelData.BlockCount+=fgetc(F);
        LevelData.EnemyCount=fgetc(F);   // Antal fiender p banan
        LevelData.EnemyCount=(LevelData.EnemyCount << 8);
        LevelData.EnemyCount+=fgetc(F);
        LevelData.ItemCount=fgetc(F);   // Antal prylar och saker p banan
        LevelData.ItemCount=(LevelData.ItemCount << 8);
        LevelData.ItemCount+=fgetc(F);
        Player.x=fgetc(F);   // Player start X
        Player.x=(Player.x << 8);
        Player.x+=fgetc(F);
        Player.y=fgetc(F);   // Player start Y
        Player.y=(Player.y << 8);
        Player.y+=fgetc(F);
        Player.StartX=Player.x;
        Player.StartY=Player.y;
       // printf("Loading %s - %i\n", LevelData.Name, LevelData.Ident);
        LevelData.LevelBitmap=create_bitmap(LevelData.Length, 190);   // Allokerar minne fr banbitmappen
        //LevelData.LevelMask=malloc(sizeof(struct TLevelMask)*((LevelData.Length*190)+10));  //Allokerar minne fr collisionmasken
        LevelData.BlockPos=malloc(sizeof(struct TItemPos)*(LevelData.BlockCount+10));  // Allokerar minne fr block
        LevelData.EnemyPos=malloc(sizeof(struct TItemPos)*(LevelData.EnemyCount+10));  // Allokerar minne fr fiender
        LevelData.ItemPos=malloc(sizeof(struct TItemPos)*(LevelData.ItemCount+10));    // Allokerar minne fr saker
        //memset(LevelData.LevelMask, 0, (LevelData.Length*190)+10);          // Nollstller alla allokerade minnesplatser
        memset(LevelData.BlockPos, 0, LevelData.BlockCount+10);
        memset(LevelData.EnemyPos, 0, LevelData.EnemyCount+10);
        memset(LevelData.ItemPos, 0, LevelData.ItemCount+10);
        clear(LevelData.LevelBitmap);
        if ((LevelData.LevelBitmap==NULL))
          equit("Error creating bitmaps!");
        else // Ladda sjlva banan...
        {
          for (i=0;i<LevelData.BlockCount;i++)
          {
            BlockType=fgetc(F);  // Hmta blocktypen
            if (BlockType<TEXTURECOUNT)  // Kontrollera om det r ett felaktigt block
            {
              x=fgetc(F);   // Hmta X och Y position fr blocket
              x=(x << 8);
              x+=fgetc(F);
              y=fgetc(F);
              y=(y << 8);
              y+=fgetc(F);
              masked_blit(Texture[BlockType].Bitmap, LevelData.LevelBitmap,  0, 0, x, y, Texture[BlockType].Width, Texture[BlockType].Height);
              LevelData.BlockPos[i].x=x;  // Sparar blocket i minnet
              LevelData.BlockPos[i].y=y;
              LevelData.BlockPos[i].ident=BlockType;
            }
          }
          for (i=0;i<LevelData.EnemyCount;i++)  // Samma som ovan fast fr fiender
          {
            BlockType=fgetc(F);
            if (BlockType<ENEMYCOUNT)
            {
              x=fgetc(F);
              x=(x << 8);
              x+=fgetc(F);
              y=fgetc(F);
              y=(y << 8);
              y+=fgetc(F);
              masked_blit(Enemy[BlockType].Bitmap1, LevelData.LevelBitmap,  0, 0, x, y, Enemy[BlockType].Bitmap1->w, Enemy[BlockType].Bitmap1->h);
              LevelData.EnemyPos[i].x=x;
              LevelData.EnemyPos[i].y=y;//+10
              LevelData.EnemyPos[i].StartX=x;
              LevelData.EnemyPos[i].StartY=y;//+10
              LevelData.EnemyPos[i].ident=BlockType;
              LevelData.EnemyPos[i].WalkDelay=WALKDELAY;
              LevelData.EnemyPos[i].Visible=TRUE;
            }
          }
          for (i=0;i<LevelData.ItemCount;i++)   // Samma som ovan fast fr saker
          {
            BlockType=fgetc(F);
            if (BlockType<ITEMCOUNT)
            {
              x=fgetc(F);
              x=(x << 8);
              x+=fgetc(F);
              y=fgetc(F);
              y=(y << 8);
              y+=fgetc(F);
              masked_blit(Item[BlockType].Bitmap1, LevelData.LevelBitmap,  0, 0, x, y, Item[BlockType].Bitmap1->w, Item[BlockType].Bitmap1->h);
              LevelData.ItemPos[i].x=x;
              LevelData.ItemPos[i].y=y;
              LevelData.ItemPos[i].ident=BlockType;
              LevelData.ItemPos[i].Visible=TRUE;
            }
          }
          textout(LevelData.LevelBitmap, font, "PS", Player.x, Player.y, 125);
        }
      }
    }
    fclose(F);

    // Anledningen till att jag inte kr load_level(char *filename) r att det krnglar lngre ner
/*loadlevel end*/

  }
  else
  {                  // Om banan nu redan skulle vara allokerad s tycker i alla fall jag att den ska avallokeras...  Eller vad sger du?
    if (LevelData.LevelBitmap!=NULL)
      unload_level();
    LevelData.BlockCount=0;
    LevelData.EnemyCount=0;
    LevelData.ItemCount=0;
    LevelData.LevelBitmap=create_bitmap(LevelData.Length, 190);   // Allokerar minne fr banbitmappen
    LevelData.BlockPos=malloc(sizeof(struct TItemPos)*(LevelData.BlockCount+10));  // Allokerar minne fr block
    LevelData.EnemyPos=malloc(sizeof(struct TItemPos)*(LevelData.EnemyCount+10));  // Allokerar minne fr fiender
    LevelData.ItemPos=malloc(sizeof(struct TItemPos)*(LevelData.ItemCount+10));    // Allokerar minne fr saker
    memset(LevelData.BlockPos, 0, LevelData.BlockCount+10);
    memset(LevelData.EnemyPos, 0, LevelData.EnemyCount+10);
    memset(LevelData.ItemPos, 0, LevelData.ItemCount+10);
    LevelData.LevelBitmap=create_bitmap(320, 190);
    clear(LevelData.LevelBitmap);
    LevelData.Length=320;
  }
  clear(screen);
  set_mouse_range(0,0,320,200);  // Ange grnserna fr hur musen fr flyttas
  position_mouse(0,0);           // och stt vart den ska brja
  set_palette(Texture[0].Pal);
  PlayerStartBitmap=create_bitmap(16, 8);
  clear(PlayerStartBitmap);
  textout(PlayerStartBitmap, font, "PS", 0, 0, 125);
  if (ItemType==0)
    set_mouse_sprite(Texture[ActiveTexture].Bitmap);  // Fixar till s att vi kan se en snygg (?) sprite istllet fr den hemska pilen :)
  if (ItemType==1)
    set_mouse_sprite(Enemy[ActiveEnemy].Bitmap1);
  if (ItemType==2)
    set_mouse_sprite(Item[ActiveItem].Bitmap1);
  if (ItemType==3)
    set_mouse_sprite(PlayerStartBitmap);
  textout(screen, font, MENUTEXT, 0,0,250);  // Jaja  Vi initierar en massa shit...
  hline(screen, 0, 9, 320, 100);
  show_mouse(screen);
  LevelData.xoff=0;
  LevelData.xinc=LevelData.xdec=FALSE;
  blit(LevelData.LevelBitmap, screen, 0,0,0,10,320,190);
  while (!done)
  {
    gKey=0;   // Denna mste nollstllas annars s blir det cp
    get_input();
    switch(gKey)  // Tangenttryckningar
    {
      case 283:   done=TRUE;  // Esc
                  break;
      case 4709:  position_mouse(mouse_x, mouse_y - Texture[ActiveTexture].Height);  // e
                  break;
      case 8550:  position_mouse(mouse_x + Texture[ActiveTexture].Width, mouse_y);   // f
                  break;
      case 8292:  position_mouse(mouse_x, mouse_y + Texture[ActiveTexture].Height);  // d
                  break;
      case 8051:  position_mouse(mouse_x - Texture[ActiveTexture].Width, mouse_y);   // s
                  break;
    }
    if (LevelData.xdec)   // Scrollar vnster
    {
      scare_mouse();  // Man mste skrmma bort musen innan man ska rita ngonting annars blir det vldigt cp
      if (LevelData.xoff>0)
      {
        LevelData.xoff--;            // Left
        blit(LevelData.LevelBitmap, screen, LevelData.xoff,0,0,10, LevelData.Length, 190);
      }
      unscare_mouse();  // Sen r det ju frsts bra att locka fram musen igen, s att vi kan beskda dess sknhet
    }
    if (LevelData.xinc)  // Scrollar hger, och utkar bitmapens storlek om det skulle behvas
    {
      scare_mouse();
      if (LevelData.xoff<(65535-320))
      {
        LevelData.xoff++;            // Right
        if (320+LevelData.xoff>LevelData.Length)
        {
          TempBitmap=create_bitmap(320+LevelData.xoff,190);  // Skapa en temporr bitmap med samma storlek
          clear(TempBitmap);
          blit(LevelData.LevelBitmap, TempBitmap, 0,0,0,0,320+LevelData.xoff-1,190);  // Kopiera till den temporra bitmapen
          destroy_bitmap(LevelData.LevelBitmap);   // Ta bort den gamla
          LevelData.LevelBitmap=create_bitmap(320+LevelData.xoff,190);  // Skapa den gamla p nytt fast lite strre
          clear(LevelData.LevelBitmap);
          blit(TempBitmap, LevelData.LevelBitmap, 0,0,0,0,320+LevelData.xoff, 190);  // Lgg tillbaka den innehllet i den nu lite strre bitmapen
          destroy_bitmap(TempBitmap);  // Ta bort tempbitmapen
          LevelData.Length=320+LevelData.xoff;  // Spara lngden i minnet
        }
        blit(LevelData.LevelBitmap, screen, LevelData.xoff,0,0,10, LevelData.Length, 190);
      }
      unscare_mouse();
    }
    if ((mouse_x>28*8) && (mouse_x<((28*8)+4*8)) && (!draw))  // Koden hr nedan fixar s att man kan klicka med musen om olika delar av texten i vre delen p skrmen
    {
      if (mouse_b==1)
      {
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        textout(screen, font, "Exit", 28*8,0,240);
        unscare_mouse();
        done=TRUE;
        while (mouse_b & 1) {}
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        unscare_mouse();
      }
    }
    if ((mouse_x>23*8) && (mouse_x<((23*8)+4*8)) && (!draw))
    {
      if (mouse_b==1)
      {
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        textout(screen, font, "Undo", 23*8,0,240);
        unscare_mouse();
        // do nothing
        while (mouse_b & 1) {}
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        unscare_mouse();
      }
    }                       // PlayerStart
    if ((mouse_x>20*8) && (mouse_x<((20*8)+2*8)) && (!draw))
    {
      if (mouse_b==1)
      {
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        textout(screen, font, "PS", 20*8,0,240);
        unscare_mouse();
        ItemType=3;
        while (mouse_b & 1) {}
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        unscare_mouse();
      }
    }                       // Texture <
    if ((mouse_x>2*8) && (mouse_x<((2*8)+8)) && (!draw))
    {
      if (mouse_b==1)
      {
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        textout(screen, font, "<", 2*8,0,240);
        unscare_mouse();
        ItemType=0;
        ActiveTexture--;
        if (ActiveTexture<0)
          ActiveTexture=TEXTURECOUNT-1;
        while (mouse_b & 1) {}
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        unscare_mouse();
      }
    }                       // Texture >
    if ((mouse_x>4*8) && (mouse_x<((4*8)+8)) && (!draw))
    {
      if (mouse_b==1)
      {
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        textout(screen, font, ">", 4*8,0,240);
        unscare_mouse();
        ItemType=0;
        ActiveTexture++;
        if (ActiveTexture==TEXTURECOUNT)
          ActiveTexture=0;
        while (mouse_b & 1) {}
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        unscare_mouse();
      }
    }                    // Texture -
    if ((mouse_x>3*8) && (mouse_x<((3*8)+8)) && (!draw))
    {
      if (mouse_b==1)
      {
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        textout(screen, font, "-", 3*8,0,240);
        unscare_mouse();
        ItemType=0;
        ActiveTexture=0;
        while (mouse_b & 1) {}
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        unscare_mouse();
      }
    }                    // Texture Text
    if ((mouse_x>0*8) && (mouse_x<((0*8)+8)) && (!draw))
    {
      if (mouse_b==1)
      {
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        textout(screen, font, "T", 0*8,0,240);
        unscare_mouse();
        ItemType=0;
        while (mouse_b & 1) {}
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        unscare_mouse();
      }
    }                    // Enemy <
    if ((mouse_x>9*8) && (mouse_x<((9*8)+8)) && (!draw))
    {
      if (mouse_b==1)
      {
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        textout(screen, font, "<", 9*8,0,240);
        unscare_mouse();
        ItemType=1;
        ActiveEnemy--;
        if (ActiveEnemy<0)
          ActiveEnemy=ENEMYCOUNT-1;
        while (mouse_b & 1) {}
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        unscare_mouse();
      }
    }                       // Enemy >
    if ((mouse_x>11*8) && (mouse_x<((11*8)+8)) && (!draw))
    {
      if (mouse_b==1)
      {
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        textout(screen, font, ">", 11*8,0,240);
        unscare_mouse();
        ItemType=1;
        ActiveEnemy++;
        if (ActiveEnemy==ENEMYCOUNT)
          ActiveEnemy=0;
        while (mouse_b & 1) {}
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        unscare_mouse();
      }
    }                        // Enemy -
    if ((mouse_x>10*8) && (mouse_x<((10*8)+8)) && (!draw))
    {
      if (mouse_b==1)
      {
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        textout(screen, font, "-", 10*8,0,240);
        unscare_mouse();
        ItemType=1;
        ActiveEnemy=0;
        while (mouse_b & 1) {}
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        unscare_mouse();
      }
    }                       // Enemy Text
    if ((mouse_x>7*8) && (mouse_x<((7*8)+8)) && (!draw))
    {
      if (mouse_b==1)
      {
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        textout(screen, font, "E", 7*8,0,240);
        unscare_mouse();
        ItemType=1;
        while (mouse_b & 1) {}
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        unscare_mouse();
      }
    }                        // Item <
    if ((mouse_x>16*8) && (mouse_x<((16*8)+8)) && (!draw))
    {
      if (mouse_b==1)
      {
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        textout(screen, font, "<", 16*8,0,240);
        unscare_mouse();
        ItemType=2;
        ActiveItem--;
        if (ActiveItem<0)
          ActiveItem=ITEMCOUNT-1;
        while (mouse_b & 1) {}
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        unscare_mouse();
      }
    }                       // Item >
    if ((mouse_x>18*8) && (mouse_x<((18*8)+8)) && (!draw))
    {
      if (mouse_b==1)
      {
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        textout(screen, font, ">", 18*8,0,240);
        unscare_mouse();
        ItemType=2;
        ActiveItem++;
        if (ActiveItem==ITEMCOUNT)
          ActiveItem=0;
        while (mouse_b & 1) {}
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        unscare_mouse();
      }
    }                        // Item -
    if ((mouse_x>17*8) && (mouse_x<((17*8)+8)) && (!draw))
    {
      if (mouse_b==1)
      {
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        textout(screen, font, "-", 17*8,0,240);
        unscare_mouse();
        ItemType=2;
        ActiveItem=0;
        while (mouse_b & 1) {}
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        unscare_mouse();
      }
    }                       // Item Text
    if ((mouse_x>14*8) && (mouse_x<((14*8)+8)) && (!draw))
    {
      if (mouse_b==1)
      {
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        textout(screen, font, "I", 14*8,0,240);
        unscare_mouse();
        ItemType=2;
        while (mouse_b & 1) {}
        scare_mouse();
        textout(screen, font, MENUTEXT, 0,0,250);
        unscare_mouse();
      }
    }
    if ((mouse_y<11) && (draw))  // Fixar s att den vanliga muspekaren syns nr man kommer till den vre delen av skrmen
    {
      set_mouse_sprite(NULL);
      draw=FALSE;
    }
    if ((mouse_y>10) && (!draw))  // Fixar tillbaka dom fina spritsen nr man kommer p ritytan
    {
      if (ItemType==0)
        set_mouse_sprite(Texture[ActiveTexture].Bitmap);  // Fixar till s att vi kan se en snygg (?) sprite istllet fr den hemska pilen :)
      if (ItemType==1)
        set_mouse_sprite(Enemy[ActiveEnemy].Bitmap1);
      if (ItemType==2)
        set_mouse_sprite(Item[ActiveItem].Bitmap1);
      if (ItemType==3)
        set_mouse_sprite(PlayerStartBitmap);
      draw=TRUE;
    }
    if ((mouse_b==1) && (draw))  // Placerar en sprite p skrmen samt sparar den i minnet
    {
      if (ItemType==0)
      {
        scare_mouse();
        LevelData.BlockPos[LevelData.BlockCount].x=mouse_x-1+LevelData.xoff;  // Spara i minnet   -1 har jag fr att musens positioner tydligen inte riktigt stmmer med skrmkoordinaterna
        LevelData.BlockPos[LevelData.BlockCount].y=mouse_y-11; // Minus 11 fr att ta bort den lilla kanten lngst  upp p skrmen som r 10 pixlar stor
        LevelData.BlockPos[LevelData.BlockCount].ident=ActiveTexture;
        LevelData.BlockCount++;
        TempPos=malloc(sizeof(struct TItemPos)*(LevelData.BlockCount+10));    // Allokerar minne fr saker
        memcpy(TempPos, LevelData.BlockPos, sizeof(struct TItemPos)*LevelData.BlockCount);
        LevelData.BlockPos=realloc(LevelData.BlockPos, sizeof(struct TItemPos)*(LevelData.BlockCount+10));
        memcpy(LevelData.BlockPos, TempPos, sizeof(struct TItemPos)*LevelData.BlockCount);
        free(TempPos);
        masked_blit(Texture[ActiveTexture].Bitmap, LevelData.LevelBitmap, 0,0,mouse_x-1+LevelData.xoff, mouse_y-11, Texture[ActiveTexture].Width, Texture[ActiveTexture].Height);
        vsync();
        hline(screen, 0, 9, 320, 100);
        blit(LevelData.LevelBitmap, screen, LevelData.xoff,0,0,10,LevelData.Length,190);
        unscare_mouse();
        while (mouse_b & 1) {}
      }
      if (ItemType==1)
      {
        scare_mouse();
        LevelData.EnemyPos[LevelData.EnemyCount].x=mouse_x-1+LevelData.xoff;
        LevelData.EnemyPos[LevelData.EnemyCount].y=mouse_y-11;
        LevelData.EnemyPos[LevelData.EnemyCount].ident=ActiveEnemy;
        LevelData.EnemyCount++;
        TempPos=malloc(sizeof(struct TItemPos)*(LevelData.EnemyCount+10));    // Allokerar minne fr saker
        memcpy(TempPos, LevelData.EnemyPos, sizeof(struct TItemPos)*LevelData.EnemyCount);
        LevelData.EnemyPos=realloc(LevelData.EnemyPos, sizeof(struct TItemPos)*(LevelData.EnemyCount+10));
        memcpy(LevelData.EnemyPos, TempPos, sizeof(struct TItemPos)*LevelData.EnemyCount);
        free(TempPos);
        masked_blit(Enemy[ActiveEnemy].Bitmap1, LevelData.LevelBitmap, 0,0,mouse_x-1+LevelData.xoff, mouse_y-11, Enemy[ActiveEnemy].Bitmap1->w, Enemy[ActiveEnemy].Bitmap1->h);
        vsync();
        hline(screen, 0, 9, 320, 100);
        blit(LevelData.LevelBitmap, screen, LevelData.xoff,0,0,10,LevelData.Length,190);
        unscare_mouse();
        while (mouse_b & 1) {}
      }
      if (ItemType==2)
      {
        scare_mouse();
        LevelData.ItemPos[LevelData.ItemCount].x=mouse_x-1+LevelData.xoff;
        LevelData.ItemPos[LevelData.ItemCount].y=mouse_y-11;
        LevelData.ItemPos[LevelData.ItemCount].ident=ActiveItem;
        LevelData.ItemCount++;
        TempPos=malloc(sizeof(struct TItemPos)*(LevelData.ItemCount+10));    // Allokerar minne fr saker
        memcpy(TempPos, LevelData.ItemPos, sizeof(struct TItemPos)*LevelData.ItemCount);
        LevelData.ItemPos=realloc(LevelData.ItemPos, sizeof(struct TItemPos)*(LevelData.ItemCount+10));
        memcpy(LevelData.ItemPos, TempPos, sizeof(struct TItemPos)*LevelData.ItemCount);
        free(TempPos);
        masked_blit(Item[ActiveItem].Bitmap1, LevelData.LevelBitmap, 0,0,mouse_x-1+LevelData.xoff, mouse_y-11, Item[ActiveItem].Bitmap1->w, Item[ActiveItem].Bitmap1->h);
        vsync();
        hline(screen, 0, 9, 320, 100);
        blit(LevelData.LevelBitmap, screen, LevelData.xoff,0,0,10,LevelData.Length,190);
        //textprintf(screen, font, 0,20,100, "X %i Y %i   ", LevelData.ItemPos[LevelData.ItemCount-1].x, LevelData.ItemPos[LevelData.ItemCount-1].y);
        unscare_mouse();
        while (mouse_b & 1) {}
      }
      if ((ItemType==3) && (!PlayerStartSet))
      {
        scare_mouse();
        Player.x=mouse_x-1+LevelData.xoff;
        Player.y=mouse_y-11;
        masked_blit(PlayerStartBitmap, LevelData.LevelBitmap, 0,0,mouse_x-1+LevelData.xoff, mouse_y-11, PlayerStartBitmap->w, PlayerStartBitmap->h);
        vsync();
        hline(screen, 0, 9, 320, 100);
        blit(LevelData.LevelBitmap, screen, LevelData.xoff,0,0,10,LevelData.Length,190);
        PlayerStartSet=TRUE;
        unscare_mouse();
        while (mouse_b & 1) {}
      }
    }
    if ((mouse_b==2) && (draw))  // Nsta textur  (Hgerknappen)
    {
      if (ItemType==0)
      {
        ActiveTexture++;
        if (ActiveTexture==TEXTURECOUNT)
          ActiveTexture=0;
        set_mouse_sprite(Texture[ActiveTexture].Bitmap);
      }
      if (ItemType==1)
      {
        ActiveEnemy++;
        if (ActiveEnemy==ENEMYCOUNT)
          ActiveEnemy=0;
        set_mouse_sprite(Enemy[ActiveEnemy].Bitmap1);
      }
      if (ItemType==2)
      {
        ActiveItem++;
        if (ActiveItem==ITEMCOUNT)
          ActiveItem=0;
        set_mouse_sprite(Item[ActiveItem].Bitmap1);
      }
      while (mouse_b & 2) {}
    }
    if ((mouse_b==4) && (draw))  // Fregende textur (Mittenknappen)
    {
    if (ItemType==0)
      {
        ActiveTexture--;
        if (ActiveTexture==-1)
          ActiveTexture=TEXTURECOUNT-1;
        set_mouse_sprite(Texture[ActiveTexture].Bitmap);
      }
    if (ItemType==1)
      {
        ActiveEnemy--;
        if (ActiveEnemy==-1)
          ActiveEnemy=ENEMYCOUNT-1;
        set_mouse_sprite(Enemy[ActiveEnemy].Bitmap1);
      }
    if (ItemType==2)
      {
        ActiveItem--;
        if (ActiveItem==-1)
          ActiveItem=ITEMCOUNT-1;
        set_mouse_sprite(Item[ActiveItem].Bitmap1);
      }
      while (mouse_b & 4) {}
    }
  }
  //  textprintf(screen, font, 0, 12, 100, "%i", F);

  // Spara banan!

  F=fopen(filename, "w");
  fseek(F, 0, SEEK_SET);
/*  textprintf(screen, font, 0, 20, 100, "%i : %i", ferror(F), F);
  readkey();*/
  fputs("LGL100", F);
  fputs("Test Level 4", F);
  fseek(F, 26, SEEK_SET);
  fputc(0xAA, F);
  fputc(hi(LevelData.Length), F);
  fputc(lo(LevelData.Length), F);
  fputc(hi(LevelData.BlockCount), F);
  fputc(lo(LevelData.BlockCount), F);
  fputc(hi(LevelData.EnemyCount), F);
  fputc(lo(LevelData.EnemyCount), F);
  fputc(hi(LevelData.ItemCount), F);
  fputc(lo(LevelData.ItemCount), F);
  fputc(hi(Player.x), F);
  fputc(lo(Player.x), F);
  fputc(hi(Player.y), F);
  fputc(lo(Player.y), F);
  for (a=0;a<LevelData.BlockCount;a++)
  {
    fputc(LevelData.BlockPos[a].ident, F);
    fputc(hi(LevelData.BlockPos[a].x), F);
    fputc(lo(LevelData.BlockPos[a].x), F);
    fputc(hi(LevelData.BlockPos[a].y), F);
    fputc(lo(LevelData.BlockPos[a].y), F);
  }
  for (a=0;a<LevelData.EnemyCount;a++)
  {
    fputc(LevelData.EnemyPos[a].ident, F);
    fputc(hi(LevelData.EnemyPos[a].x), F);
    fputc(lo(LevelData.EnemyPos[a].x), F);
    fputc(hi(LevelData.EnemyPos[a].y), F);
    fputc(lo(LevelData.EnemyPos[a].y), F);
  }
  for (a=0;a<LevelData.ItemCount;a++)
  {
    fputc(LevelData.ItemPos[a].ident, F);
    fputc(hi(LevelData.ItemPos[a].x), F);
    fputc(lo(LevelData.ItemPos[a].x), F);
    fputc(hi(LevelData.ItemPos[a].y), F);
    fputc(lo(LevelData.ItemPos[a].y), F);
  }
  fclose(F);
  //save_pcx("Levelbmp1.pcx" ,LevelData.LevelBitmap, Texture[0].Pal);
  return 0;
}

int load_textures()
{
  int j;
  char *TextureFilename[TEXTURECOUNT];
  char *PlayerTextureFilename;
  TextureFilename[0]="Block1.pcx";
  TextureFilename[1]="Block2.pcx";
  TextureFilename[2]="Block3.pcx";
  TextureFilename[3]="Block4.pcx";
  TextureFilename[4]="Block5.pcx";
  TextureFilename[5]="Block6.pcx";
  TextureFilename[6]="Topp1.pcx";
  TextureFilename[7]="Pipe1.pcx";
  for (j=0;j<TEXTURECOUNT;j++)
  {
    Texture[j].Bitmap=load_bitmap(TextureFilename[j], Texture[j].Pal);
    Texture[j].Width=Texture[j].Bitmap->w;
    Texture[j].Height=Texture[j].Bitmap->h;
  }
  PlayerTextureFilename="Player1.pcx";
  Player.Bitmap1=load_bitmap(PlayerTextureFilename, Player.Pal);
  PlayerTextureFilename="Player2.pcx";
  Player.Bitmap2=load_bitmap(PlayerTextureFilename, Player.Pal);
  TextureFilename[0]="Enemy1.pcx";
  TextureFilename[1]="Enemy2.pcx";
  TextureFilename[2]="Enemy3.pcx";
  for (j=0;j<ENEMYCOUNT;j++)
  {
    Enemy[j].Bitmap1=load_bitmap(TextureFilename[j], Enemy[j].Pal);
    Enemy[j].Bitmap2=load_bitmap(TextureFilename[j], Enemy[j].Pal);
  }
  TextureFilename[0]="Item1.pcx";
  TextureFilename[1]="Item2.pcx";
  TextureFilename[2]="Item3.pcx";
  for (j=0;j<ITEMCOUNT;j++)
  {
    Item[j].Bitmap1=load_bitmap(TextureFilename[j], Item[j].Pal);
    Item[j].Bitmap2=load_bitmap(TextureFilename[j], Item[j].Pal);
  }
  TextureFilename[0]="Backgr.bmp";
  LevelData.Background=load_bitmap(TextureFilename[0], LevelData.Pal);
  if (!NOMUSIC)
  {
    SndSample[0].Sample=MIDASloadWaveSample("Snd1.wav", MIDAS_LOOP_NO);
    SndSample[1].Sample=MIDASloadWaveSample("Snd2.wav", MIDAS_LOOP_NO);
    SndSample[2].Sample=MIDASloadWaveSample("Snd3.wav", MIDAS_LOOP_NO);
    SndSample[3].Sample=MIDASloadWaveSample("Snd4.wav", MIDAS_LOOP_NO);
  }
  return 0;
}

int remove_textures()
{
  int a;
  for (a=0;a<TEXTURECOUNT;a++)
  {
    if (Texture[a].Bitmap!=NULL)
      destroy_bitmap(Texture[a].Bitmap);
    Texture[a].Width=0;
    Texture[a].Height=0;
  }
  destroy_bitmap(Player.Bitmap1);
  destroy_bitmap(Player.Bitmap2);
  for (a=0;a<ENEMYCOUNT;a++)
  {
    if (Enemy[a].Bitmap1!=NULL)
      destroy_bitmap(Enemy[a].Bitmap1);
    if (Enemy[a].Bitmap2!=NULL)
      destroy_bitmap(Enemy[a].Bitmap2);
  }
  for (a=0;a<ITEMCOUNT;a++)
  {
    if (Item[a].Bitmap1!=NULL)
      destroy_bitmap(Item[a].Bitmap1);
    if (Enemy[a].Bitmap2!=NULL)
      destroy_bitmap(Item[a].Bitmap2);
  }
  destroy_bitmap(LevelData.Background);
  if (!NOMUSIC)
  {
    MIDASfreeSample(SndSample[0].Sample);
    MIDASfreeSample(SndSample[1].Sample);
    MIDASfreeSample(SndSample[2].Sample);
    MIDASfreeSample(SndSample[3].Sample);
  }
  return 0;
}

void WaitRefr()
{
  Refr=TRUE;
}


int main(int argc, char *argv[])
{
  int done=FALSE;
  int i, j;
  clrscr();
  if (strcmp(argv[1], "create")==0)
    Design=TRUE;
  else
    Design=FALSE;
  gfxmode=GFX_TEXT;
  allegro_init();
  if ((!Design))
  {
    MIDASstartup();
    MIDASdetectSoundCard();
    MIDASinit();
    MIDASopenChannels(17);
    if (!NOMUSIC)
      testmod=MIDASloadModule("testmod.mod");
    if (!NOSYNC)
      MIDASsetTimerCallbacks(GAMESPEED , TRUE, &WaitRefr, NULL, NULL);
  }
  install_keyboard();
  keyboard_lowlevel_callback=&KeyRelease;  // Fixa s att KeyRelease() krs vid varje keyboard interupt
  if (Design)
    install_timer();
  mouseen=TRUE;
  if (Design)
    install_mouse();
  joyen=TRUE;
  if (joyen)
    install_joystick(JOY_TYPE_AUTODETECT);

  printf("Legion Game 1\n---------------------------\n\n");
  printf("e, Upp   - Jump\nf, Right   - Right\ns, Left   - Left\nEsc - Quit\n\n");

  clear_keybuf();
  gKey=0;
  load_textures();
if (Design)
{
/*  if (strcmp(argv[2],"")==0)
    argv[1]="level1.lev";*/
  if (argc<2)
    argv[1]="level1.lev";
  printf("\n[Starting LG Game 1!]\n  - Switching to graphics mode... Press [Enter]\n");
  readkey();
  if (set_gfx_mode(GFX_VGA, 320, 200, 0, 0)<0)
    equit("Setting VGA graphics mode (320*200*256c)!");
  //printf(" OK!\n");
  gfxmode=GFX_VGA;
  design_new_level(argv[2]);
}
else
{
 /* if (strcmp(argv[1],"")==0)
    argv[1]="level1.lev";*/
  if (argc<2)
    argv[1]="level1.lev";
  //Player.x=0;
  //Player.y=10;
  load_level(argv[1]);
  printf("\n[Starting LG Game 1!]\n  - Switching to graphics mode... Press [Enter]\n");
  readkey();
  if (set_gfx_mode(GFX_VGA, 320, 200, 0, 0)<0)
    equit("Setting VGA graphics mode (320*200*256c)!");
  //printf(" OK!\n");
  gfxmode=GFX_VGA;

  Vir1=create_bitmap(320, 200);
  clear(Vir1);
  //save_pcx("Levelbmp.pcx" ,LevelData.LevelBitmap, Texture[0].Pal);
  done=FALSE;
/*  Player.x=80;
  Player.y=10; */
  Player.xdec=Player.xinc=FALSE;
  Player.fall=FALSE;
  Player.Score=0;
  Player.Dir=0;
  Player.Health=3;
  Player.Blink=FALSE;
  Player.BlinkCount=0;
//  Enemy[0].x=50;
//  Enemy[0].y=168-18;

/*  Enemy[0].x=50;
  Enemy[0].y=20;
  Enemy[0].Dir=0;
  Enemy[0].xdec=TRUE;
  Enemy[0].xinc=FALSE;*/
  for (i=0;i<LevelData.EnemyCount;i++)
  {
    LevelData.EnemyPos[i].Dir=0;
    LevelData.EnemyPos[i].xdec=TRUE;
    LevelData.EnemyPos[i].xinc=FALSE;
  }
  LevelData.xoff=0;
  set_palette(Texture[0].Pal);

  if ((!Design) && (!NOMUSIC))
  {
    playHandle=MIDASplayModule(testmod, TRUE);
  }
  readkey();
  while (done==FALSE)
  {
    gKey=0;
    get_input();
    switch(gKey)
    {
      case 283:  done=TRUE;
                 break;
    }
/*    if //(joy[0].stick[0].axis[0].pos>10)
           (joy[0].stick[0].axis[0].d2)
    {
      Player.xincj=TRUE;
      Player.xdecj=FALSE;
      Player.Dir=0;
    }
    if //(joy[0].stick[0].axis[0].pos<-10)
         (joy[0].stick[0].axis[0].d1)
    {
      Player.xdecj=TRUE;
      Player.xincj=FALSE;
      Player.Dir=1;
    }
    if //((joy[0].stick[0].axis[0].pos>-10) && (joy[0].stick[0].axis[0].pos<10))
    ((!joy[0].stick[0].axis[0].d1) && (!joy[0].stick[0].axis[0].d2))
    {
      Player.xdecj=FALSE;
      Player.xincj=FALSE;
    }
    if //((joy[0].stick[0].axis[1].pos<-10) && (!Player.jump) && (!Player.fall))
         ((joy[0].button[0].b) && (!Player.jump) && (!Player.fall))
    {
      Player.jump=TRUE;
      Player.jumpx=Player.x;
      Player.jumpy=Player.y;
      JumpPathNum=0;
    }*/
    update_level();
    update_items();
    update_enemies();
    update_player();
    //vsync();
    if (!NOSYNC)
      while (!Refr) {}
    blit(Vir1, screen, 0,0,0,0, 320,200);
    Refr=FALSE;
  }
  //clear(screen);
}
  if ((!Design))
  {
    if (!NOMUSIC)
      MIDASstopModule(playHandle);
    if (!NOMUSIC)
      MIDASfreeModule(testmod);
    MIDASclose();
  }
  remove_textures();
  if (set_gfx_mode(GFX_TEXT, 640, 480, 0, 0)<0)
    equit("Setting TEXT mode!");
  printf("Back to DOS!\n");
  if (joyen)
     remove_joystick();
  if (Design)
    remove_mouse();
  if (Design)
    remove_timer();
  remove_keyboard();
  allegro_exit();
  return 0;
}
